import { AxiosRequestConfig, AxiosRequestHeaders } from 'axios';
import { HTTP_METHODS } from '../enums';
export declare enum JsonApiLinkFields {
    first = "first",
    last = "last",
    next = "next",
    prev = "prev",
    self = "self"
}
export declare type Uuid = string;
export declare type Url = string;
export declare type Endpoint = string;
export declare type JsonApiClientConfig = {
    baseUrl?: Url;
    authToken?: Uuid;
};
export declare type JsonApiClientRequestConfigHeaders = AxiosRequestHeaders;
export declare type JsonApiClientRequestParams = unknown;
export declare type JsonApiClientRequestConfig = AxiosRequestConfig;
export declare type JsonApiErrorMetaType = Record<string, unknown> | unknown[] | unknown;
export declare type JsonApiErrorBaseNestedErrors = Record<string, unknown>[];
export declare type JsonApiKey = {
    id?: Uuid;
    type: string;
};
export declare type JsonApiAttribute = string | number | string[] | boolean | undefined;
export declare type JsonApiRawRelationship = {
    data: JsonApiKey;
};
export declare type JsonApiRawResource = JsonApiKey & {
    attributes?: Record<string, JsonApiAttribute>;
    relationshipNames?: Record<string, JsonApiRawRelationship>;
};
export declare type JsonApiPayload = {
    data: JsonApiRawResource;
};
export declare type JsonApiRelationship = Record<string, unknown>;
export declare type JsonApiRelationships = Record<string, JsonApiRelationship | JsonApiRelationship[]>;
export declare type JsonApiRecordBase<T extends string> = {
    id: Uuid;
    type: T;
    relationshipNames?: JsonApiRelationships;
};
export declare type JsonApiRecord = JsonApiRecordBase<string> & Record<string, JsonApiAttribute | JsonApiRelationships>;
export declare type JsonApiResponseData = JsonApiRecord | JsonApiRecord[];
export declare type JsonApiResponseLinks = {
    first?: Endpoint;
    last?: Endpoint;
    next?: Endpoint;
    prev?: Endpoint;
    self?: Endpoint;
};
export declare type JsonApiClientRequestOpts = {
    endpoint: Endpoint;
    method: HTTP_METHODS;
    headers?: JsonApiClientRequestConfigHeaders;
    data?: unknown;
    query?: unknown;
    contentType?: string;
    isEmptyBodyAllowed?: boolean;
    needRaw?: boolean;
    withCredentials?: boolean;
};
